Affine

Struct Affine 

pub struct Affine<P: DOCurveConfig> { /* private fields */ }
Affine coordinates for a point on an elliptic curve in double-odd form, over the base field P::BaseField.

Instead of using the (x,y)-coordinate system of the original double-odd paper (https://doubleodd.group/doubleodd.pdf), the (e,u)-coordinate system from the follow-up paper (https://doubleodd.group/doubleodd-jq.pdf) was implemented. This coordinate system allows for the new curve equation e**2 = (a-4*b)*u**4 - 2a*u**2 + 1, which is of the Jacobi quartic form, allowing for faster addition/doubling formulae. Additionally, these coordinates allow for more efficient en/decoding.

  • In general: P = (e,u) = (u**2*(x - b/x),x/y)
  • P and P+N are representants of the same group element.
  • P+N = (-e,-u), -P = (e,-u), and -P+N = (-e,u)
  • The group neutral is represented by the point at infinity O = (1,0) and N = O+N = (-1,0)

Implementations

Source

impl<P: DOCurveConfig> Affine<P>

pub fn new(e: P::BaseField, u: P::BaseField) -> Self

pub const fn new_unchecked(e: P::BaseField, u: P::BaseField) -> Self

pub const fn identity() -> Self

Returns one of the representants for the identity, namely the point-at-infinity (1,0).

The other representant N=(-1,0) of the identity could also be returned, but the implementation of formulas only requires one representant.

pub fn get_point_from_u_unchecked( u: P::BaseField, greatest: bool, ) -> Option<Self>

pub fn get_e_from_u(u: P::BaseField) -> Option<P::BaseField>

pub fn get_es_from_u_unchecked( u: P::BaseField, ) -> Option<(P::BaseField, P::BaseField)>

pub fn is_on_curve(&self) -> bool

Checks if self is a valid point on the curve, using the curve equation e**2 = (a-4*b)*u**4 - 2a*u**2 + 1